@@ -1,6 +1,6 @@
 {-# LANGUAGE Haskell2010 #-}
 {-# LANGUAGE TypeFamilies, RankNTypes, FlexibleContexts, ScopedTypeVariables #-}
-{-# LANGUAGE AllowAmbiguousTypes #-}
+{-# LANGUAGE TypeOperators, AllowAmbiguousTypes #-}
 
 module Simple14 where
 
@@ -19,12 +19,11 @@ ntI :: (forall p. EQ_ x y -> p) -> EQ_ x y
 ntI x = error "ntI"
 
 foo :: forall m n. EQ_ (Maybe m) (Maybe n)
-foo = ntI (\x -> x `eqE` (eqI :: EQ_ m n))
-
--- Alternative
--- foo = ntI (\eq -> eq `eqE` (eqI :: EQ_ m n))
+foo = ntI (\eq -> eq `eqE` (eqI :: EQ_ m n))
+-- Aug 2024: this test started passing with the fix to #25029
+-- See Note [Defaulting equalities] in GHC.Tc.Solver
 
 -- eq :: EQ_ (Maybe m) (Maybe n)
 -- Need (Maybe m ~ Maybe n) =>  EQ_ m n ~ EQ_ zeta zeta
--- which reduces to (m~n) => m ~ zeta
--- but then we are stuck
+-- which reduces to (m~n) => m ~ zeta, but then
+-- we were stuck; now we default zeta:=m in tryDefaulting
