@@ -1,11 +1,10 @@
-{-# LANGUAGE Haskell2010 #-}
 {-# LANGUAGE PolyKinds, GADTs #-}
 
 module T7053a where
 
 import Data.Kind (Type)
 
--- This time with a fully-specified kind signature
-data TypeRep (a :: k) :: Type where
+type TypeRep :: k -> Type
+data TypeRep a where
    TyApp   :: TypeRep a -> TypeRep b -> TypeRep (a b)
 
