@@ -3,7 +3,7 @@
 module T12373 where
 
 import GHC.MVar
-import GHC.Prim
+import GHC.Exts
 import GHC.Types
 
 main :: IO ()
